=== modified file 'lib/canonical/launchpad/browser/bugtarget.py'
--- lib/canonical/launchpad/browser/bugtarget.py	2006-02-23 23:34:49 +0000
+++ lib/canonical/launchpad/browser/bugtarget.py	2006-03-28 20:39:09 +0000
@@ -6,12 +6,14 @@
 
 __all__ = ["FileBugView"]
 
+from zope.app.form.interfaces import IInputWidget
+from zope.app.form.utility import setUpWidgets
 from zope.component import getUtility
 
-from canonical.launchpad.webapp import canonical_url
+from canonical.launchpad.browser.addview import SQLObjectAddView
 from canonical.launchpad.interfaces import (
     ILaunchBag, IDistribution, IProduct, NotFoundError)
-from canonical.launchpad.browser.addview import SQLObjectAddView
+from canonical.launchpad.webapp import canonical_url
 
 class FileBugView(SQLObjectAddView):
     """Browser view for filebug forms.
@@ -23,7 +25,7 @@
     notification = "Thank you for your bug report."
 
     def create(self, title=None, comment=None, private=False,
-               packagename=None, distribution=None):
+               packagename=None, distribution=None, security_related=False):
         """Add a bug to this IBugTarget."""
         current_user = getUtility(ILaunchBag).user
         context = self.context
@@ -54,15 +56,18 @@
                             "was not published in %s."
                             % (packagename, context.displayname))
                 bug = context.createBug(
-                    title=title, comment=comment, private=private, owner=current_user)
+                    title=title, comment=comment, private=private,
+                    security_related=security_related, owner=current_user)
             else:
                 bugtarget = context.getSourcePackage(sourcepackagename.name)
                 bug = bugtarget.createBug(
-                    title=title, comment=comment, private=private, owner=current_user,
+                    title=title, comment=comment, private=private,
+                    security_related=security_related, owner=current_user,
                     binarypackagename=binarypackagename)
         else:
             bug = context.createBug(
-                title=title, comment=comment, private=private, owner=current_user)
+                title=title, comment=comment, private=private,
+                security_related=security_related, owner=current_user)
 
         self.addedBug = bug
         return self.addedBug
@@ -74,3 +79,7 @@
         task = self.addedBug.bugtasks[0]
         return canonical_url(task)
 
+    def _setUpWidgets(self):
+        # Customize the onKeyPress event of the package name chooser.
+        setUpWidgets(self, self.schema, IInputWidget, names=self.fieldNames)
+        self.packagename_widget.onKeyPress = "selectWidget('choose', event)"

=== modified file 'lib/canonical/launchpad/browser/distribution.py'
--- lib/canonical/launchpad/browser/distribution.py	2006-03-22 12:15:46 +0000
+++ lib/canonical/launchpad/browser/distribution.py	2006-03-28 20:39:09 +0000
@@ -111,8 +111,9 @@
     usedfor = IDistribution
     facet = 'overview'
     links = ['search', 'allpkgs', 'milestone_add', 'members', 'edit',
-             'editbugcontact', 'reassign', 'addrelease', 'builds',
-             'officialmirrors', 'allmirrors', 'newmirror', 'launchpad_usage']
+             'editbugcontact', 'securitycontact', 'reassign', 'addrelease',
+             'builds', 'officialmirrors', 'allmirrors', 'newmirror',
+             'launchpad_usage']
 
     @enabled_with_permission('launchpad.Edit')
     def edit(self):
@@ -125,6 +126,11 @@
         return Link('+editbugcontact', text, icon='edit')
 
     @enabled_with_permission('launchpad.Edit')
+    def securitycontact(self):
+        text = 'Change Security Contact'
+        return Link('+securitycontact', text, icon='edit')
+
+    @enabled_with_permission('launchpad.Edit')
     def reassign(self):
         text = 'Change Admin'
         return Link('+reassign', text, icon='edit')

=== modified file 'lib/canonical/launchpad/browser/product.py'
--- lib/canonical/launchpad/browser/product.py	2006-03-24 10:51:39 +0000
+++ lib/canonical/launchpad/browser/product.py	2006-03-28 20:39:09 +0000
@@ -148,7 +148,7 @@
     usedfor = IProduct
     facet = 'overview'
     links = [
-        'edit', 'reassign', 'distributions', 'packages',
+        'edit', 'reassign', 'securitycontact', 'distributions', 'packages',
         'branches', 'branch_add', 'series_add', 'milestone_add',
         'launchpad_usage', 'administer', 'rdf']
 
@@ -162,6 +162,11 @@
         text = 'Change Maintainer'
         return Link('+reassign', text, icon='edit')
 
+    @enabled_with_permission('launchpad.Edit')
+    def securitycontact(self):
+        text = 'Change Security Contact'
+        return Link('+securitycontact', text, icon='edit')
+
     def distributions(self):
         text = 'Distributions'
         return Link('+distributions', text, icon='info')

=== added file 'lib/canonical/launchpad/browser/securitycontact.py'
--- lib/canonical/launchpad/browser/securitycontact.py	1970-01-01 00:00:00 +0000
+++ lib/canonical/launchpad/browser/securitycontact.py	2006-03-28 20:39:09 +0000
@@ -0,0 +1,32 @@
+# Copyright 2006 Canonical Ltd.  All rights reserved.
+
+"""Browser view classes for security contacts."""
+
+__metaclass__ = type
+__all__ = ["SecurityContactEditView"]
+
+from canonical.launchpad.webapp import canonical_url
+
+class SecurityContactEditView:
+    """Browser view for editing the security contact.
+
+    self.context is assumed to implement IHasSecurityContact.
+    """
+
+    @property
+    def initial_values(self):
+        return {
+            'security_contact': self.context.security_contact}
+
+    def process(self, security_contact):
+        self.context.security_contact = security_contact
+        if security_contact:
+            self.request.response.addNotification(
+                "Successfully set the security contact to %s" %
+                security_contact.preferredemail.email)
+        else:
+            self.request.response.addNotification(
+                "Successfully removed the security contact")
+
+    def nextURL(self):
+        return canonical_url(self.context)

=== modified file 'lib/canonical/launchpad/database/bug.py'
--- lib/canonical/launchpad/database/bug.py	2006-03-28 17:13:10 +0000
+++ lib/canonical/launchpad/database/bug.py	2006-03-28 20:39:09 +0000
@@ -361,9 +361,9 @@
         bug.subscribe(owner)
         # Subscribe the security contact, for security-related bugs.
         if security_related:
-            if product:
+            if product and product.security_contact:
                 bug.subscribe(product.security_contact)
-            else:
+            elif distribution and distribution.security_contact:
                 bug.subscribe(distribution.security_contact)
 
         # Link the bug to the message.

=== modified file 'lib/canonical/launchpad/pagetitles.py'
--- lib/canonical/launchpad/pagetitles.py	2006-03-24 10:51:39 +0000
+++ lib/canonical/launchpad/pagetitles.py	2006-03-28 20:39:09 +0000
@@ -673,6 +673,8 @@
     return '%s release series: %s' % (
         context.product.displayname, context.displayname)
 
+security_contact = ContextDisplayName("Edit %s security contact")
+
 shipit_index = 'ShipIt'
 
 shipit_exports = 'ShipIt exports'

=== modified file 'lib/canonical/launchpad/templates/bugtarget-filebug.pt'
--- lib/canonical/launchpad/templates/bugtarget-filebug.pt	2006-03-28 17:13:10 +0000
+++ lib/canonical/launchpad/templates/bugtarget-filebug.pt	2006-03-28 20:39:09 +0000
@@ -5,6 +5,11 @@
 
   <div metal:fill-slot="main">
 
+  <p class="error message"
+     tal:define="status view/update"
+     tal:condition="status"
+     tal:content="status" />
+
   <tal:uses_malone tal:condition="context/official_malone">
     <p>
       Before reporting a bug, please ensure it hasn&#8217;t been <a
@@ -24,6 +29,11 @@
     </p>
   </tal:not_uses_malone>
 
+  <form action="." 
+        tal:attributes="action request/URL" 
+        method="post"
+        enctype="multipart/form-data">
+
   <div tal:condition="view/packagename_widget|nothing">
     <label tal:attributes="for view/packagename_widget/name">
       In what package did you find this bug?
@@ -37,7 +47,8 @@
         </label>
       </li>
       <li style="margin-top: 4px">
-        <input type="radio" name="packagename_option" value="choose" />
+        <input type="radio" name="packagename_option" value="choose"
+               id="choose" />
         <span tal:content="structure view/packagename_widget" />
       </li>
     </ul>
@@ -65,7 +76,9 @@
       <i tal:condition="context/security_contact">
         The security contact for
         <span tal:content="context/displayname" />,
-        <span tal:content="context/security_contact/displayname" />,
+        <a href="#"
+            tal:content="context/security_contact/displayname"
+            tal:attributes="href context/security_contact/fmt:url" />,
         will be Cc'd to this bug
       </i>
       <i tal:condition="not:context/security_contact">
@@ -87,6 +100,11 @@
     </label>
   </div>
 
+  <div style="margin-top: 1em">
+    <input type="submit" name="UPDATE_SUBMIT" value="Submit Bug Report" />
+  </div>
+
+  </form>
   </div>
 
 </html>

=== modified file 'lib/canonical/launchpad/templates/bugtask-assignee-widget.pt'
--- lib/canonical/launchpad/templates/bugtask-assignee-widget.pt	2005-12-14 20:32:49 +0000
+++ lib/canonical/launchpad/templates/bugtask-assignee-widget.pt	2006-03-28 20:39:09 +0000
@@ -1,18 +1,5 @@
 <tal:assigneewidget define="widget_name string:${view/name}.option">
 
-
-  <script type="text/javascript">
-  <!--
-  function selectAssignTo(widget, event) {
-    if (event && event.keyCode == 9)
-        // avoid firing if user is tabbing through
-        return;
-    document.getElementById('assign_to').checked = true;
-  }
-  //-->
-  </script>
-
-
   <label style="font-weight: normal"
          tal:attributes="for view/assign_to_nobody">
     <input type="radio"

=== modified file 'lib/canonical/launchpad/templates/distribution-portlet-details.pt'
--- lib/canonical/launchpad/templates/distribution-portlet-details.pt	2006-02-20 10:08:18 +0000
+++ lib/canonical/launchpad/templates/distribution-portlet-details.pt	2006-03-28 20:39:09 +0000
@@ -15,6 +15,28 @@
     <a tal:attributes="href string:${context/fmt:url}/+members"
        tal:content="context/members/browsername">members name</a><br /> 
 
+    <b>Bug contact:</b><br />
+    <span tal:condition="context/bugcontact">
+      <img src="/@@/user.gif">
+      <a tal:attributes="href string:${context/fmt:url}/+editbugcontact"
+         tal:content="context/bugcontact/browsername">foo bar</a>
+    </span>
+    <span tal:condition="not:context/bugcontact">
+      <i>None</i>
+    </span>
+    <br />
+
+    <b>Security contact:</b><br />
+    <span tal:condition="context/security_contact">
+      <img src="/@@/user.gif">
+      <a tal:attributes="href string:${context/fmt:url}/+securitycontact"
+         tal:content="context/security_contact/browsername">sample person</a>
+    </span>
+    <span tal:condition="not:context/security_contact">
+      <i>None</i>
+    </span>
+    <br />
+
     <b>Translation group:</b><br />
     <img src="/@@/languages.gif">
     <tal:block condition="context/translationgroup">

=== modified file 'lib/canonical/launchpad/templates/launchpad.js'
--- lib/canonical/launchpad/templates/launchpad.js	2006-02-16 05:42:38 +0000
+++ lib/canonical/launchpad/templates/launchpad.js	2006-03-28 20:39:09 +0000
@@ -282,3 +282,10 @@
     //     break;
     }
 }
+
+function selectWidget(widget_name, event) {
+  if (event && event.keyCode == 9)
+      // avoid firing if user is tabbing through
+      return;
+  document.getElementById(widget_name).checked = true;
+}

=== modified file 'lib/canonical/launchpad/templates/product-portlet-details.pt'
--- lib/canonical/launchpad/templates/product-portlet-details.pt	2006-03-02 20:37:11 +0000
+++ lib/canonical/launchpad/templates/product-portlet-details.pt	2006-03-28 20:39:09 +0000
@@ -19,6 +19,28 @@
       </a>
       <br />
 
+      <b>Bug contact:</b><br />
+      <span tal:condition="context/bugcontact">
+        <img src="/@@/user.gif">
+        <a tal:attributes="href string:${context/fmt:url}/+editbugcontact"
+           tal:content="context/bugcontact/browsername">foo bar</a>
+      </span>
+      <span tal:condition="not:context/bugcontact">
+        <i>None</i>
+      </span>
+      <br />
+
+      <b>Security contact:</b><br />
+      <span tal:condition="context/security_contact">
+        <img src="/@@/user.gif">
+        <a tal:attributes="href string:${context/fmt:url}/+securitycontact"
+           tal:content="context/security_contact/browsername">sample person</a>
+      </span>
+      <span tal:condition="not:context/security_contact">
+        <i>None</i>
+      </span>
+      <br />
+
       <b>Translation group:</b><br />
       <img src="/@@/languages.gif">
       <tal:block condition="context/translationgroup">

=== modified file 'lib/canonical/launchpad/templates/security-contact.pt'
--- lib/canonical/launchpad/templates/security-contact.pt	2006-03-28 17:13:10 +0000
+++ lib/canonical/launchpad/templates/security-contact.pt	2006-03-28 20:39:09 +0000
@@ -1,1 +1,29 @@
-blah
\ No newline at end of file
+<html
+    xmlns="http://www.w3.org/1999/xhtml"
+    xml:lang="en"
+    lang="en"
+    metal:use-macro="context/@@main_template/master"
+    i18n:domain="launchpad">
+
+<body>
+
+<metal:rightportlets fill-slot="portlets_two">
+</metal:rightportlets>
+
+<div metal:fill-slot="main">
+
+  <div metal:use-macro="context/@@launchpad_generalform/generalform">
+
+    <h1 tal:condition="view/label"
+        tal:content="view/label"
+        metal:fill-slot="heading">Form Label comes from ZCML label="xxx"</h1>
+
+    <div metal:fill-slot="extra_info" class="documentDescription">
+      When a bug is reported as a security vulnerability, the security
+      contact is automatically subscribed to the bug.
+    </div>
+  </div>
+
+</div>
+</body>
+</html>

=== modified file 'lib/canonical/launchpad/zcml/product.zcml'
--- lib/canonical/launchpad/zcml/product.zcml	2006-03-16 19:32:18 +0000
+++ lib/canonical/launchpad/zcml/product.zcml	2006-03-28 20:39:09 +0000
@@ -257,18 +257,18 @@
         name="+filebug"
         for="canonical.launchpad.interfaces.IProduct"
         schema="canonical.launchpad.interfaces.IBugAddForm"
-        fields="title comment private"
+        fields="title comment private security_related"
         class="canonical.launchpad.browser.FileBugView"
         facet="bugs"
         arguments=""
-        keyword_arguments="title comment private"
+        keyword_arguments="title comment private security_related"
         permission="launchpad.AnyPerson"
         template="../templates/bugtarget-filebug.pt"
         lp:url="/products/$Product.name/+filebug">
         <browser:widget
            field="title"
            class="zope.app.form.browser.TextWidget"
-           displayWidth="30"
+           displayWidth="50"
            extra="tabindex=1" />
         <browser:widget
            field="comment"
@@ -276,9 +276,13 @@
            extra="tabindex=2"
            width="62" />
         <browser:widget
+           field="security_related"
+           class="zope.app.form.browser.CheckBoxWidget"
+           extra="tabindex=3" />
+        <browser:widget
            field="private"
            class="zope.app.form.browser.CheckBoxWidget"
-           extra="tabindex=3" />
+           extra="tabindex=4" />
     </browser:addform>
 
     <browser:addform

=== modified file 'lib/canonical/launchpad/zcml/securitycontact.zcml'
--- lib/canonical/launchpad/zcml/securitycontact.zcml	2006-03-28 17:13:10 +0000
+++ lib/canonical/launchpad/zcml/securitycontact.zcml	2006-03-28 20:39:09 +0000
@@ -8,6 +8,8 @@
       name="+securitycontact"
       for="canonical.launchpad.interfaces.IHasSecurityContact"
       schema="canonical.launchpad.interfaces.IHasSecurityContact"
+      class="canonical.launchpad.browser.securitycontact.SecurityContactEditView"
+      facet="overview"
       permission="launchpad.Edit"
       fields="security_contact"
       keyword_arguments="security_contact"

=== modified file 'lib/canonical/widgets/bugtask.py'
--- lib/canonical/widgets/bugtask.py	2006-03-10 10:14:27 +0000
+++ lib/canonical/widgets/bugtask.py	2006-03-28 20:39:09 +0000
@@ -41,7 +41,7 @@
 
         self.assignee_chooser_widget = SinglePopupWidget(
             context, context.vocabulary, request)
-        self.assignee_chooser_widget.onKeyPress = "selectAssignTo(this, event)"
+        self.assignee_chooser_widget.onKeyPress = "selectWidget('assign_to', event)"
 
         # Set some values that will be used as values for the input
         # widgets.

